@@ -38,7 +38,7 @@ use CGI::FormBuilder;
 use HTML::Entities;
 use URI::Escape;
 
-our $VERSION = '1.00';
+our $VERSION = '1.00_01';
 
 =encoding utf8
 
@@ -787,13 +787,15 @@ sub _create_add_edit_route {
         ),
     );
     for my $field (@editable_columns) {
-        # values_from_database contains what was in the database for this 
-        # object, if it already existed in the database.  $args->{default_value}
-        # is the default, if any, requested by the user for this field in the 
+        # first check if there's data from the database for this field,
+        # then if there's a value in params() for this field,
+        # then if args->{default_value} was set for this field via the
         # 'default_value' hash when the route was created.
         my $default = 
                 exists $values_from_database->{$field}  
               ? $values_from_database->{$field}
+              : exists params->{$field} 
+              ? uri_unescape(params->{$field})
               : exists $args->{default_value}->{$field} 
               ? $args->{default_value}->{$field}
               : '';
@@ -958,6 +960,7 @@ sub _create_list_handler {
         }
     }
 
+    my $searchfield = params->{searchfield} || $key_column;
     my $searchfield_options = join(
         "\n",
         map {
@@ -966,24 +969,30 @@ sub _create_list_handler {
                 $friendly_name = $args->{labels}{$_->{COLUMN_NAME}};
             }
             my $sel
-                = (defined params->{searchfield}
-                    && params->{searchfield} eq $_->{COLUMN_NAME})
+                = ($searchfield eq $_->{COLUMN_NAME})
                 ? "selected"
                 : "";
             "<option $sel value='$_->{COLUMN_NAME}'>$friendly_name</option>"
             } @$columns
     );
+    my $default_searchtype = "e";
     my @searchtypes = (
-        [ c => "Contains" ],
-        [ e => "Equals" ],
-        [ nc => "Does Not Contain" ],
-        [ ne => "Does Not Equal" ],
+        [ e   => { name => "Equals",           cmp => "=" } ],
+        [ c   => { name => "Contains",         cmp => "like" } ],
+        [ ne  => { name => "Does Not Equal",   cmp => "!=" } ],
+        [ nc  => { name => "Does Not Contain", cmp => "not like" } ],
+
+        [ lt  => { name => "Less Than",                cmp => "<" } ],
+        [ lte => { name => "Less Than or Equal To",    cmp => "<=" } ],
+        [ gt  => { name => "Greater Than",             cmp => ">" } ],
+        [ gte => { name => "Greater Than or Equal To", cmp => ">=" } ],
     );
     my $searchtype_options = join( "\n",
         map { 
-            my ($search_code, $string) = @$_;
-            my $sel = _defined_or_empty(params->{searchtype}) eq $search_code;
-            sprintf("<option value='%s'%s>%s</option>", $search_code, $sel ? " selected" : "", $string);
+            my ($search_code, $hashref) = @$_;
+            my $name = $hashref->{name};
+            my $sel = (params->{searchtype} || $default_searchtype) eq $search_code;
+            sprintf("<option value='%s'%s>%s</option>", $search_code, $sel ? " selected" : "", $name);
         } @searchtypes 
     );
 
@@ -1124,13 +1133,13 @@ SEARCHFORM
         my (@search_wheres, @search_binds);
         if (length $q) {    # this nested code is all for queries in $q
             my ($column_data)
-                = grep { lc $_->{COLUMN_NAME} eq lc params->{searchfield} }
+                = grep { lc $_->{COLUMN_NAME} eq lc $searchfield }
                 @{$columns};
             debug(
                 "Searching on $column_data->{COLUMN_NAME} which is a "
                 . "$column_data->{TYPE_NAME}"
             );
-            my $st = params->{searchtype};
+            my $st = params->{searchtype} || $default_searchtype;
 
             if ($column_data) {
                 my $search_value = $q;
@@ -1138,13 +1147,12 @@ SEARCHFORM
                     $search_value = '%' . $search_value . '%';
                 }
 
+                my ($searchtype_row) = grep { $_->[0] eq $st } @searchtypes;
+                my $cmp = $searchtype_row->[1]->{cmp} || '=';
                 push(@search_wheres,
                     "$table_name."
-                    . $dbh->quote_identifier(params->{searchfield})
-                    . ($st eq 'c' ? ' LIKE ' :
-                       $st eq 'nc' ? ' NOT LIKE ' :
-                       $st eq 'ne' ? ' != ' : ' = ')
-                   . '?' );
+                    . $dbh->quote_identifier($searchfield)
+                    . " $cmp ?" );
                 push(@search_binds, $search_value);
 
                 my $matchtype = $st eq "c" ? "contains": 
@@ -1153,7 +1161,7 @@ SEARCHFORM
                 $html
                     .= sprintf(
                     "<p>Showing results from searching for '%s' %s '%s'",
-                    encode_entities(params->{searchfield}), $matchtype, encode_entities($q)
+                    encode_entities($searchfield), $matchtype, encode_entities($q)
                 );
                 $html .= sprintf '&mdash;<a href="%s">Reset search</a></p>',
                     _external_url($args->{dancer_prefix}, $args->{prefix});
@@ -1166,8 +1174,8 @@ SEARCHFORM
 
     if ($args->{downloadable}) {
         my $qt   = uri_escape($q);
-        my $sf   = uri_escape(params->{searchfield} || "");
-        my $st   = uri_escape(params->{searchtype} || "");
+        my $sf   = uri_escape($searchfield);
+        my $st   = uri_escape(params->{searchtype} || $default_searchtype);
         my $o    = uri_escape(params->{'o'}         || "");
         my $d    = uri_escape(params->{'d'}         || "");
         my $page = uri_escape(params->{'p'}         || 0);
@@ -1186,8 +1194,8 @@ SEARCHFORM
     my %columns_sort_options;
     if ($args->{sortable}) {
         my $qt              = uri_escape($q);
-        my $sf              = uri_escape(params->{searchfield} || "");
-        my $st              = uri_escape(params->{searchtype} || "");
+        my $sf              = uri_escape($searchfield);
+        my $st              = uri_escape(params->{searchtype} || $default_searchtype);
         my $order_by_column = uri_escape(params->{'o'})        || $key_column;
 
         # Invalid column name ? discard it
@@ -1256,8 +1264,8 @@ SEARCHFORM
         my $page_size = $args->{paginate};
 
         my $qt   = uri_escape($q);
-        my $sf   = uri_escape(params->{searchfield} || "");
-        my $st   = uri_escape(params->{searchtype} || "");
+        my $sf   = uri_escape($searchfield);
+        my $st   = uri_escape(params->{searchtype} || $default_searchtype);
         my $o    = uri_escape(params->{'o'}         || "");
         my $d    = uri_escape(params->{'d'}         || "");
         my $page = uri_escape(params->{'p'}         || 0);
